==> maven-archetype-3.0.1-source-release.zip: maven-archetype-3.0.1/maven-archetype-plugin/src/main/java/org/apache/maven/archetype/ui/generation/ArchetypeGenerationQueryer.java <==
package org.apache.maven.archetype.ui.generation;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.maven.archetype.ui.ArchetypeConfiguration;
import org.codehaus.plexus.components.interactivity.PrompterException;

import java.util.regex.Pattern;

/**
 * User interaction component to query informations necessary for a project generation from an archetype.
 * 
 * @todo this interface is bound to its implementation through the prompter exception
 */
public interface ArchetypeGenerationQueryer
{
    boolean confirmConfiguration( ArchetypeConfiguration archetypeConfiguration )
        throws PrompterException;

    String getPropertyValue( String requiredProperty, String defaultValue, Pattern validationRegex )
        throws PrompterException;
}

==> maven-archetype-3.1.2-source-release.zip: maven-archetype-3.1.2/maven-archetype-plugin/src/main/java/org/apache/maven/archetype/ui/generation/ArchetypeGenerationQueryer.java <==
package org.apache.maven.archetype.ui.generation;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.maven.archetype.ui.ArchetypeConfiguration;
import org.codehaus.plexus.components.interactivity.PrompterException;

import java.util.regex.Pattern;

/**
 * <p>User interaction component to query informations necessary for a project generation from an archetype.</p>
 * 
 * TODO this interface is bound to its implementation through the prompter exception
 */
public interface ArchetypeGenerationQueryer
{
    boolean confirmConfiguration( ArchetypeConfiguration archetypeConfiguration )
        throws PrompterException;

    String getPropertyValue( String requiredProperty, String defaultValue, Pattern validationRegex )
        throws PrompterException;
}
